@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: cms_plugins.py 11069 2018-05-21 10:18:52Z Lavender $
+# $Id: cms_plugins.py 11152 2018-07-08 08:27:01Z Lavender $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2018-05-21 18:18:52 +0800 (週一, 21 五月 2018) $
-# $Revision: 11069 $
+# $Date: 2018-07-08 17:27:01 +0900 (週日, 08 七月 2018) $
+# $Revision: 11152 $
 
 from cms.plugin_base import CMSPluginBase
 from cms.plugin_pool import plugin_pool
@@ -49,8 +49,18 @@ class FilterArticlePlugin(CMSPluginBase):
                 queryset = queryset.filter(tags__name=tag.name)
 
         if instance.catagory:
+            stack = [instance.catagory, ]
+            categoryList = []
+            while stack:
+                category = stack.pop()
+                if not category in categoryList:
+                    categoryList.append(category)
+
+                for child in category.get_children():
+                    stack.append(child)
+
             queryset = queryset.filter(
-                categories__in=[instance.catagory])
+                categories__in=categoryList)
 
         if queryset.count() >= instance.limit:
             articles = queryset[:instance.limit]
