@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: models.py 11103 2018-06-13 14:19:09Z Lavender $
+# $Id: models.py 11142 2018-07-07 13:50:30Z Lavender $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,14 +12,17 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2018-06-13 22:19:09 +0800 (週三, 13 六月 2018) $
-# $Revision: 11103 $
+# $Date: 2018-07-07 22:50:30 +0900 (週六, 07 七月 2018) $
+# $Revision: 11142 $
 
+from functools import wraps
+from django import forms
 from django.db import models
 from django.conf import settings
 from django.utils.translation import ugettext_lazy as _
 from cms.models import CMSPlugin
 from aldryn_categories.models import Category
+from aldryn_newsblog.models import Article
 from taggit.models import Tag
 
 from Zephyrus.blog_extension import settings as _settings
@@ -60,3 +63,29 @@ class FilterPlugin(CMSPlugin):
     )
 
 
+# modify slug field formfield
+def formfieldDecorator(f):
+    @wraps(f)
+    def wrapper(*args, **kwds):
+        return f(form_class=forms.CharField ,*args, **kwds)
+    return wrapper
+
+for field in Article.translations.related.related_model._meta.fields:
+    if field.attname == 'slug':
+        field.default_validators = []
+        field.validators = []
+        field.formfield = formfieldDecorator(field.formfield)
+
+for field in Category.translations.related.related_model._meta.fields:
+    if field.attname == 'slug':
+        field.default_validators = []
+        field.validators = []
+        field.formfield = formfieldDecorator(field.formfield)
+
+for field in Tag._meta.fields:
+    if field.attname == 'slug':
+        field.default_validators = []
+        field.validators = []
+        field.formfield = formfieldDecorator(field.formfield)
+
+
