@@ -28,7 +28,8 @@ from cms import cms_toolbars
 from menus.utils import set_language_changer
 
 from aldryn_newsblog import views
-from aldryn_newsblog.views import ArticleDetail 
+from aldryn_newsblog.views import (
+    ArticleDetail, CategoryArticleList, TagArticleList)
 
 class ArticleDetail2(ArticleDetail):
     def get(self, request, *args, **kwargs):
@@ -76,6 +77,7 @@ class ArticleDetail2(ArticleDetail):
 views.ArticleDetail = ArticleDetail2
 
 from aldryn_newsblog.urls import urlpatterns
+from aldryn_newsblog.feeds import TagFeed, CategoryFeed
 
 urlpatterns += [
     url(r'^(?P<slug>.*)/$',
@@ -86,4 +88,14 @@ urlpatterns += [
         ArticleDetail2.as_view(), name='article-detail'),
     url(r'^(?P<year>\d{4})/(?P<month>\d{1,2})/(?P<day>\d{1,2})/(?P<slug>.*)/$',
         ArticleDetail2.as_view(), name='article-detail'),
+
+    url(r'^category/(?P<category>.*)/$',
+        CategoryArticleList.as_view(), name='article-list-by-category'),
+    url(r'^category/(?P<category>.*)/feed/$',
+        CategoryFeed(), name='article-list-by-category-feed'),
+
+    url(r'^tag/(?P<tag>.*)/$',
+        TagArticleList.as_view(), name='article-list-by-tag'),
+    url(r'^tag/(?P<tag>.*)/feed/$',
+        TagFeed(), name='article-list-by-tag-feed'),
 ]
\ No newline at end of file
